@@ -1,7 +1,7 @@
 use v6;
 use fatal;
 
-unit class Getopt::Long:ver<0.1.3>;
+unit class Getopt::Long:ver<0.1.4>;
 
 my sub null-converter(Str:D $value --> Str) {
 	return $value;
@@ -283,7 +283,7 @@ method new-from-sub(Sub $main) {
 	return self.new(:%options);
 }
 
-method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$bundling = True, :$write-args) {
+method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$bundling = True, :$compat-singles = False, :$write-args) {
 	my @list;
 	while @args {
 		my $head = @args.shift;
@@ -360,6 +360,11 @@ method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$
 			take-value($option, ~$<value>);
 			take-args($option);
 		}
+		elsif $compat-singles && $head ~~ / ^ '-' $<name>=<alnum> '=' $<value>=[.*] / -> $/ {
+			my $option = get-option($<name>);
+			die Exception.new("$<name> doesn't take one argument") if $option.arity.max != 1;
+			take-value($option, ~$<value>);
+		}
 		else {
 			if $permute {
 				@list.push: $head;
@@ -509,7 +514,7 @@ or
 
 =head1 Getting Started with Getopt::Long
 
-To use Getopt::Long from a Perl6 program, you must include the
+To use Getopt::Long from a Raku program, you must include the
 following line in your program:
 
     use Getopt::Long;
@@ -960,6 +965,15 @@ arguments and option settings are:
 
 =end item
 
+=begin item
+compat-singles (default: disabled)
+
+Enabling this will allow single letter arguments with an C<=> between
+the letter and its argument. E.g. C<-j=2> instead of C<-j2>. This is for
+compatibility with raku's built-in argument parsing.
+
+=end item
+
 =head1 Return values and Errors
 
 C<get-options> returns a capture to indicate success.
